@@ -2,7 +2,7 @@ package Acme::PrettyCure::Girl::CureEgret;
 use utf8;
 use Any::Moose;
 
-with 'Acme::PrettyCure::Girl::Role';
+with qw/Acme::PrettyCure::Girl::Role Acme::PrettyCure::Girl::Role::Futari/;
 
 sub human_name   {'美翔舞'}
 sub precure_name {'キュアイーグレット'}
@@ -25,14 +25,6 @@ before 'transform' => sub {
     die "咲がいないと変身できないチョピ!" unless ref($buddy) =~ /Cure(Bloom|Bright)/;
 };
 
-after 'transform' => sub {
-    my ($self, $buddy) = @_;
-
-    unless ($buddy->is_precure) {
-        $buddy->transform($self);
-    }
-};
-
 use Acme::PrettyCure::Girl::CureWindy;
 sub powerup { Acme::PrettyCure::Girl::CureWindy->new(is_precure => shift->is_precure) }
 
