@@ -2,7 +2,7 @@ package Acme::PrettyCure::Girl::CurePeach;
 use utf8;
 use Any::Moose;
 
-with 'Acme::PrettyCure::Girl::Role';
+with qw/Acme::PrettyCure::Girl::Role Acme::PrettyCure::Girl::Role::Fresh/;
 
 sub human_name   {'桃園ラブ'}
 sub precure_name {'キュアピーチ'}
