@@ -1,6 +1,6 @@
 package Acme::PrettyCure::Girl::Role::Five;
 use utf8;
-use Moo::Role;
+use Any::Moose '::Role';
 
 
 after 'transform' => sub {
